nozama-cloudsearch-model
===================================

.. contents::


Introduction
------------

This provides the namespaced package: nozama.cloudsearch.model


Testing
-------

Activate the dev environment and change into nozama-cloudsearch-model.

Run all tests
~~~~~~~~~~~~~

From here you can do::

    python runtests.py -s


